import { DB, DBConnectorModel, DBConnectorFilterQuery, DBConnectorDocument } from '@yeeti/modules-db';
import { DBModelInterface } from '.';
export declare class DBModel implements DBModelInterface {
    /**
     * Database instance
     */
    db: DB;
    /**
     * Model client (mongoose.connect().model result)
     */
    client: DBConnectorModel;
    /**
     * Initialize DB Model
     * @param db Databse Instance
     */
    constructor(db: DB);
    /**
     * Model name (defaulted to contructor.name)
     */
    name(): string;
    /**
     * Dictionary of Model properties
     */
    properties(): {
        [key: string]: any;
    };
    /**
     * List of indexes
     */
    indexes(): Array<{
        [key: string]: 1 | -1;
    }>;
    /**
     * Attach current model to DB instance
     */
    attachToDB(): DBConnectorModel;
    /**
     * Count how many documents in Model with conditions
     * @param conditions model properties to filter
     */
    count(conditions: DBConnectorFilterQuery): Promise<number>;
    /**
     * Check if a document exists with conditions
     * @param conditions model properties to filter
     */
    exists(conditions: DBConnectorFilterQuery): Promise<boolean>;
    /**
     * Create a new document with data
     * @param data data to create document
     */
    create(data: any): Promise<DBConnectorDocument>;
}
//# sourceMappingURL=db-model.d.ts.map